"use strict";

function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
var React = require('react');
var _merge = require('lodash/merge');
var StyleConstants = require('../constants/Style');
var _require = require('../constants/App'),
  themeShape = _require.themeShape;
var StyleUtils = {
  adjustColor: function adjustColor(col, amt) {
    var color = col;
    var usePound = false;
    if (color[0] === '#') {
      // remove hash sign
      color = color.slice(1);
      usePound = true;
    }

    // turn it into a 6 digit string
    var colorPadded = color.padStart(6, '0');

    // subtract amount from each individual red green blue value
    var intRVal = parseInt(colorPadded.slice(0, 2), 16) + amt;
    var intGVal = parseInt(colorPadded.slice(2, 4), 16) + amt;
    var intBVal = parseInt(colorPadded.slice(4, 6), 16) + amt;
    if (intRVal > 255) {
      intRVal = 255;
    } else if (intRVal < 0) {
      intRVal = 0;
    }
    if (intGVal > 255) {
      intGVal = 255;
    } else if (intGVal < 0) {
      intGVal = 0;
    }
    if (intBVal > 255) {
      intBVal = 255;
    } else if (intBVal < 0) {
      intBVal = 0;
    }

    // pad each 2 digit hex value to ensure it is in the correct format for css
    var hexR = intRVal.toString(16).padStart(2, '0');
    var hexG = intGVal.toString(16).padStart(2, '0');
    var hexB = intBVal.toString(16).padStart(2, '0');

    // concatenate the 3 values
    return (usePound ? '#' : '') + (hexR + hexG + hexB);
  },
  adjustHexOpacity: function adjustHexOpacity(color, opacity) {
    var r = parseInt(color.slice(1, 3), 16);
    var g = parseInt(color.slice(3, 5), 16);
    var b = parseInt(color.slice(5, 7), 16);
    return 'rgba(' + r + ', ' + g + ', ' + b + ', ' + opacity + ')';
  },
  linearGradient: function linearGradient(startColor) {
    var startOpacity = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0.8;
    var endColor = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : startColor;
    var endOpacity = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
    return "linear-gradient(".concat(StyleUtils.adjustHexOpacity(startColor, startOpacity), ", ").concat(StyleUtils.adjustHexOpacity(endColor, endOpacity), ")");
  },
  getWindowSize: function getWindowSize(breakPoints) {
    var width = window.innerWidth;
    var windowSize = 'small';
    if (width >= breakPoints.large) {
      windowSize = 'large';
    } else if (width >= breakPoints.medium) {
      windowSize = 'medium';
    }
    return windowSize;
  },
  /**
   * Abstraction to simplify merging theme colors.
   *
   * @param {Object} theme - Override keys in StyleConstants
   * @returns {Object}
   */
  mergeTheme: function mergeTheme(theme) {
    return _merge({}, StyleConstants, theme);
  },
  /**
   * Inject a theme object that has already merged StyleConstants
   * @param {*} Component - a React component
   */
  withMergedTheme: function withMergedTheme(Component) {
    var WrappedComponent = function WrappedComponent(props) {
      var theme = StyleUtils.mergeTheme(props.theme);
      return /*#__PURE__*/React.createElement(Component, _extends({}, props, {
        theme: theme
      }));
    };
    WrappedComponent.propTypes = {
      theme: themeShape
    };
    return WrappedComponent;
  }
};
module.exports = StyleUtils;